/*
 *  UMMine.h
 *  
 *
 *  Created by devin delong on 5/25/07.
 *  Copyright 2007 __MyCompanyName__. All rights reserved.
 *
 */

#ifndef UMMINE_H
#define UMMINE_H

//bzfs
#include "bzfsAPI.h"

//boost
#include <boost/array.hpp>

#define kMineShotID 100
#define kMineShotIDMax 142


class UMMine {
public: 
  //The player who left the mine
  int playerID;
  //The position of the mine.
  boost::array<float, 3> pos;   
  //Controls the blast radius.
  float duration;
  
  UMMine();
  UMMine(int id, const boost::array<float, 3>& position);
  virtual ~UMMine() { }
  
  //Blows up the mine
  virtual void fire() = 0;
};

inline
UMMine::UMMine() : playerID(-1), duration(0)
{
  pos.assign(0);
}

inline
UMMine::UMMine(int id, const boost::array<float, 3>& position) 
: playerID(id), pos(position), duration(0)
{ }



// Fires a shock wave.
class ShockWaveMine : public UMMine {
public: 
  ShockWaveMine() {}
  ShockWaveMine(int id, const boost::array<float, 3>& position);  
  virtual void fire();
};

inline 
ShockWaveMine::ShockWaveMine(int id, const boost::array<float, 3>& position) 
: UMMine(id, position)
{ }



class SphericalRegMine : public UMMine {
public:
  SphericalRegMine() {}
  SphericalRegMine(int id, const boost::array<float, 3>& position);  
  virtual void fire();
};

inline
SphericalRegMine::SphericalRegMine(int id, const boost::array<float, 3>& position) 
: UMMine(id, position)
{ 
  duration = static_cast<float>(bz_getBZDBDouble("_shockOutRadius") / 
                                (bz_getBZDBDouble("_rFireAdVel") * bz_getBZDBDouble("_shotSpeed")) * 4);
}


class CylindricalRegMine : public UMMine {
public:
  CylindricalRegMine() {}
  CylindricalRegMine(int id, const boost::array<float, 3>& position);  
  virtual void fire();
};

inline
CylindricalRegMine::CylindricalRegMine(int id, const boost::array<float, 3>& position)
: UMMine(id, position)
{ 
  duration = static_cast<float>(bz_getBZDBDouble("_shockOutRadius") / 
                                (bz_getBZDBDouble("_rFireAdVel") * bz_getBZDBDouble("_shotSpeed")) * 4);
}


#endif /* UMMINE_H */
